@@ -44,6 +44,7 @@
 #include "../ui-common/menu-ops.h"
 
 static const char * const gtkui_defaults[] = {
+    "infoarea_show_art", "TRUE",
     "infoarea_show_vis", "TRUE",
     "infoarea_visible", "TRUE",
     "menu_visible", "TRUE",
@@ -197,7 +198,7 @@ static void button_add_pressed ()
     audgui_run_filebrowser (false);
 }
 
-static void title_change (void * = nullptr)
+static void title_change ()
 {
     delayed_title_change.stop ();
 
@@ -434,7 +435,7 @@ static void ui_playback_begin ()
 
     /* If "title change" is not called by 1/4 second after starting playback,
      * show "Buffering ..." as the window title. */
-    delayed_title_change.queue (250, title_change, nullptr);
+    delayed_title_change.queue (250, title_change);
 }
 
 static void ui_playback_ready ()
@@ -473,11 +474,12 @@ static GtkToolItem * toolbar_button_add (GtkWidget * toolbar,
 }
 
 static GtkToolItem * toggle_button_new (const char * icon, const char * tooltip,
- void (* toggled) (GtkToggleToolButton *))
+ void (* toggled) (GtkToggleToolButton *), bool is_toggled)
 {
     GtkToolItem * item = gtk_toggle_tool_button_new ();
     gtk_tool_button_set_icon_name ((GtkToolButton *) item, icon);
     gtk_tool_item_set_tooltip_text (item, tooltip);
+    gtk_toggle_tool_button_set_active ((GtkToggleToolButton *) item, is_toggled);
     g_signal_connect (item, "toggled", (GCallback) toggled, nullptr);
     return item;
 }
@@ -656,7 +658,11 @@ static void toggle_record (GtkToggleToolButton * button)
 
 static void toggle_search_tool (GtkToggleToolButton * button)
 {
-    aud_plugin_enable (search_tool, gtk_toggle_tool_button_get_active (button));
+    bool enable = gtk_toggle_tool_button_get_active (button);
+    aud_plugin_enable (search_tool, enable);
+
+    if (enable)
+        layout_focus (search_tool);
 }
 
 static bool search_tool_toggled (PluginHandle * plugin, void *)
@@ -794,10 +800,9 @@ bool GtkUI::init ()
     /* search button */
     if (search_tool)
     {
-        search_button = toggle_button_new ("edit-find", _("Search Library"), toggle_search_tool);
+        search_button = toggle_button_new ("edit-find", _("Search Library"),
+         toggle_search_tool, aud_plugin_get_enabled (search_tool));
         gtk_toolbar_insert ((GtkToolbar *) toolbar, search_button, -1);
-        gtk_toggle_tool_button_set_active ((GtkToggleToolButton *) search_button,
-         aud_plugin_get_enabled (search_tool));
         aud_plugin_add_watch (search_tool, search_tool_toggled, nullptr);
     }
 
@@ -813,8 +818,10 @@ bool GtkUI::init ()
     button_stop = toolbar_button_add (toolbar, aud_drct_stop, "media-playback-stop", _("Stop"));
     toolbar_button_add (toolbar, aud_drct_pl_next, "media-skip-forward", _("Next"));
 
-    button_record = toggle_button_new ("media-record", _("Record Stream"), toggle_record);
+    button_record = toggle_button_new ("media-record", _("Record Stream"),
+     toggle_record, aud_get_bool ("record"));
     gtk_widget_set_no_show_all ((GtkWidget *) button_record, true);
+    gtk_widget_set_visible ((GtkWidget *) button_record, aud_drct_get_record_enabled ());
     gtk_toolbar_insert ((GtkToolbar *) toolbar, button_record, -1);
 
     gtk_toolbar_insert ((GtkToolbar *) toolbar, gtk_separator_tool_item_new (), -1);
@@ -844,9 +851,11 @@ bool GtkUI::init ()
     gtk_toolbar_insert ((GtkToolbar *) toolbar, gtk_separator_tool_item_new (), -1);
 
     /* repeat and shuffle buttons */
-    button_repeat = toggle_button_new ("media-playlist-repeat", _("Repeat"), toggle_repeat);
+    button_repeat = toggle_button_new ("media-playlist-repeat", _("Repeat"),
+     toggle_repeat, aud_get_bool ("repeat"));
     gtk_toolbar_insert ((GtkToolbar *) toolbar, button_repeat, -1);
-    button_shuffle = toggle_button_new ("media-playlist-shuffle", _("Shuffle"), toggle_shuffle);
+    button_shuffle = toggle_button_new ("media-playlist-shuffle", _("Shuffle"),
+     toggle_shuffle, aud_get_bool ("shuffle"));
     gtk_toolbar_insert ((GtkToolbar *) toolbar, button_shuffle, -1);
 
     /* volume button */
@@ -918,8 +927,6 @@ bool GtkUI::init ()
 
     title_change ();
 
-    update_toggles ();
-
     gtk_widget_show_all (vbox_outer);
 
     menu_rclick = make_menu_rclick (accel);
@@ -1020,6 +1027,7 @@ void show_hide_menu ()
         {
             menu_button = gtk_toggle_tool_button_new ();
             gtk_tool_button_set_icon_name ((GtkToolButton *) menu_button, "audacious");
+            gtk_tool_item_set_tooltip_text (menu_button, _("Menu"));
             g_signal_connect (menu_button, "destroy", (GCallback)
              gtk_widget_destroyed, & menu_button);
             gtk_widget_show ((GtkWidget *) menu_button);
@@ -1040,6 +1048,7 @@ void show_hide_infoarea ()
         gtk_box_pack_end ((GtkBox *) vbox, infoarea, false, false, 0);
         gtk_widget_show_all (infoarea);
 
+        show_hide_infoarea_art ();
         show_hide_infoarea_vis ();
     }
 
@@ -1050,6 +1059,11 @@ void show_hide_infoarea ()
     }
 }
 
+void show_hide_infoarea_art ()
+{
+    ui_infoarea_show_art (aud_get_bool ("gtkui", "infoarea_show_art"));
+}
+
 void show_hide_infoarea_vis ()
 {
     /* only turn on visualization if interface is shown */
