@@ -57,6 +57,7 @@ typedef struct {
     AudguiPixbuf pb, last_pb;
     float alpha, last_alpha;
 
+    bool show_art;
     bool stopped;
 } UIInfoArea;
 
@@ -212,7 +213,9 @@ static void draw_title (cairo_t * cr)
     GtkAllocation alloc;
     gtk_widget_get_allocation (area->main, & alloc);
 
-    int x = HEIGHT;
+    int x = area->show_art ? HEIGHT : SPACING;
+    int y_offset1 = ICON_SIZE / 2;
+    int y_offset2 = ICON_SIZE * 3 / 4;
     int width = alloc.width - x;
 
     if (area->title)
@@ -222,16 +225,16 @@ static void draw_title (cairo_t * cr)
         draw_text (area->main, cr, x, SPACING, width, 1, 1, 1, area->last_alpha,
          "18", area->last_title);
     if (area->artist)
-        draw_text (area->main, cr, x, SPACING + ICON_SIZE / 2, width, 1, 1, 1,
+        draw_text (area->main, cr, x, SPACING + y_offset1, width, 1, 1, 1,
          area->alpha, "9", area->artist);
     if (area->last_artist)
-        draw_text (area->main, cr, x, SPACING + ICON_SIZE / 2, width, 1, 1, 1,
+        draw_text (area->main, cr, x, SPACING + y_offset1, width, 1, 1, 1,
          area->last_alpha, "9", area->last_artist);
     if (area->album)
-        draw_text (area->main, cr, x, SPACING + ICON_SIZE * 3 / 4, width, 0.7,
+        draw_text (area->main, cr, x, SPACING + y_offset2, width, 0.7,
          0.7, 0.7, area->alpha, "9", area->album);
     if (area->last_album)
-        draw_text (area->main, cr, x, SPACING + ICON_SIZE * 3 / 4, width, 0.7,
+        draw_text (area->main, cr, x, SPACING + y_offset2, width, 0.7,
          0.7, 0.7, area->last_alpha, "9", area->last_album);
 }
 
@@ -295,8 +298,13 @@ static void set_album_art ()
 {
     g_return_if_fail (area);
 
-    area->pb = audgui_pixbuf_request_current ();
+    if (! area->show_art)
+    {
+        area->pb = AudguiPixbuf ();
+        return;
+    }
 
+    area->pb = audgui_pixbuf_request_current ();
     if (area->pb)
         audgui_pixbuf_scale_within (area->pb, ICON_SIZE);
     else
@@ -348,6 +356,16 @@ static void realize_cb (GtkWidget * widget)
     gdk_window_ensure_native (gtk_widget_get_window (widget));
 }
 
+void ui_infoarea_show_art (bool show)
+{
+    if (! area)
+        return;
+
+    area->show_art = show;
+    set_album_art ();
+    gtk_widget_queue_draw (area->main);
+}
+
 void ui_infoarea_show_vis (bool show)
 {
     if (! area)
